package cz.jzitnik.game;

import cz.jzitnik.game.items.InventoryItem;
import cz.jzitnik.game.items.Item;
import cz.jzitnik.tui.Sprite;
import cz.jzitnik.tui.SpriteList;
import lombok.Getter;
import org.jline.terminal.Terminal;

import java.util.ArrayList;
import java.util.List;

@Getter
public class Inventory {
    private static final int INVENTORY_SIZE_PX = 470;

    private List<InventoryItem> items = new ArrayList<>();

    public void addItem(Item item) {
        if (!item.isStackable()) {
            items.add(new InventoryItem(item));
            return;
        }

        var it = items.stream().filter(i -> i.getItem().equals(item)).toList();
        if (!it.isEmpty()) {
            it.get(0).setAmount(it.get(0).getAmount() + 1);

            return;
        }

        items.add(new InventoryItem(item));
    }

    public void renderHotbar(StringBuilder buffer, SpriteList spriteList, Terminal terminal) {
        int termWidth = terminal.getWidth();
        int startLeft = (termWidth / 2) - (INVENTORY_SIZE_PX / 2);

        List<Sprite> sprites = items.subList(0, Math.min(9, items.size())).stream().map(items -> spriteList.getSprite(items.getItem().getSprite())).toList();
        List<String> strings = sprites.stream().map(Sprite::getSprite).toList();

        for (int i = 0; i < 26; i++) {
            // Empty left space
            buffer.append("\033[0m ".repeat(Math.max(0, startLeft)));

            if (i == 0 || i == 25) {
                buffer.append("\033[38;5;231;48;5;231m▓".repeat(INVENTORY_SIZE_PX - 2));
            } else {
                for (int j = 0; j < 9; j++) {
                    buffer.append("\033[38;5;231;48;5;231m▓".repeat(2));
                    if (strings.size() <= j) {
                        buffer.append("\033[0m ".repeat(50));
                        continue;
                    }

                    String x = strings.get(j).split("\n")[i];
                    buffer.append(x);
                }
            }
            buffer.append("\033[38;5;231;48;5;231m▓".repeat(2));
            buffer.append("\033[0m\n");
        }
    }
}
